% PicoScope units setting area !!!

% switching channels on/off
for k = UnitNumber
    for kk = 1:4
        Channel = PS4000_Channel{kk}; % A-0, B-1, C-2, D-3
        if ChannelVRange(k,kk)==0
            Enabled = int16(0); % 1-Yes, 2-No
            VRange = 0;
        else
            Enabled = int16(1); % 1-Yes, 2-No
            VRange = ChannelPRange{k,kk};
        end
        Coupling = int16(1); % 1-DC, 0-AC;
        Status = calllib('ps4000','ps4000SetChannel',UnitHandle(k),Channel,Enabled,Coupling,VRange);
        if ChannelVRange(k,kk)==0
            disp(strcat('CloseChannel___',num2str(Channel),'=',num2str(Status)))
        else
            disp(strcat('OpeningChannel_',num2str(Channel),'=',num2str(Status),'-(',ChannelPRange{k,kk},')'))
        end
    end
end
%%
% memory devision
for k = UnitNumber
    NSegments = uint16(MemSegmentNum);
    nMaxSamples = int32(0);
    nMaxSamples_ptr(k) = libpointer('int32Ptr',nMaxSamples);
    [Status nMaxSamples] = calllib('ps4000','ps4000MemorySegments',UnitHandle(k),NSegments,nMaxSamples);
    disp(strcat('MemorySegments=',num2str(Status)))
end

% Time/sample base settings
for k = UnitNumber
    TimeInterval = TimeBase;
    OverSamle = int16(1);
    MaxSamples = int32(0);
    MaxSamples_ptr(k) = libpointer('int32Ptr',MaxSamples);
    SegmentIndex = uint16(0);
    [Status TimeInterval MaxSamples] = calllib('ps4000','ps4000GetTimebase',UnitHandle(k),TimeBase,NoOfSamples,TimeInterval,OverSamle,nMaxSamples,SegmentIndex);
    disp(strcat('GetTimebase=',num2str(Status)))
end
%%
% Set trigger properties

for k = UnitNumber
    TriggerConditions_ptr = libstruct('tTriggerConditions',tTriggerConditions(k));
    nConditions = int16(1);
    [Status] = calllib('ps4000','ps4000SetTriggerChannelConditions',UnitHandle(k),tTriggerConditions(k),nConditions);
    disp(strcat('TriggerSet=',num2str(Status)));

    channelA = 'NONE';
    channelB = 'NONE';
    channelC = 'NONE';
    channelD = 'NONE';
    switch Trigger(k).Channel
        case 1
            channelA = Trigger(k).Direction;
        case 2
            channelB = Trigger(k).Direction;
        case 3
            channelC = Trigger(k).Direction;
        case 4
            channelD = Trigger(k).Direction;
    end
    ext = 'NONE';
    aux = 'NONE';
    [Status] = calllib('ps4000','ps4000SetTriggerChannelDirections',UnitHandle(k),channelA,channelB,channelC,channelD,ext,aux);
    disp(strcat('TriggerDirections=',num2str(Status)));

    TriggerChannelPropertie_ptr = libstruct('tTriggerChannelProperties',tTriggerChannelProperties(k));
    nChannelProperites = int16(1);
    auxOutputEnable = int16(0);
    autoTriggerMilliseconds = uint32(AutoTriggerMilliseconds);
    [Status] = calllib('ps4000','ps4000SetTriggerChannelProperties',UnitHandle(k),TriggerChannelPropertie_ptr,nChannelProperites,auxOutputEnable,autoTriggerMilliseconds);
    disp(strcat('TriggerSet=',num2str(Status)));

    Delay = Trigger(k).Delay;
    [Status] = calllib('ps4000','ps4000SetTriggerDelay',UnitHandle(k),Delay);
    disp(strcat('TriggerDelay=',num2str(Status)));
end

%%
time1 = clock;
for k = UnitNumber
    PreTrigSampl = int32(Trigger(k).Position);
    PostTrigSampl = int32(int32(NoOfSamples)-PreTrigSampl);
    OverSamle = int16(1);
    SegmentIndex = uint16(0);
    Ready = int32(0);
    [Status] = calllib('ps4000wrap','RunBlock',UnitHandle(k),PreTrigSampl,PostTrigSampl,TimeBase,OverSamle,SegmentIndex);
%     disp(strcat('RecordReady=',num2str(get(Ready_ptr(k),'value'))));
%     while not(get(Ready_ptr(k),'value'))
%         pause(0.005)
%     end
%     disp(strcat('RecordReady=',num2str(get(Ready_ptr(k),'value'))))
    disp(strcat('Measure=',num2str(Status)));
end
% time2 = clock;
% disp(strcat('TimeMeas=',num2str(etime(time2,time1))))
pause(5)

%%
Data = zeros(NoOfSamples,1);
Buffer_ptr = libpointer('int16Ptr',Data);
BufferLth = NoOfSamples;
figure;
for k = UnitNumber
    time1 = clock;
    for kk = find(ChannelVRange(k,:)>0)
        Channel = PS4000_Channel{kk}; % A-0, B-1, C-2, D-3
        [Status] = calllib('ps4000','ps4000SetDataBuffer',UnitHandle(k),Channel,Buffer_ptr,BufferLth);
        disp(strcat('BufferAllocation=',num2str(Status),'(',num2str(BufferLth),'Samples)'));
        pause(1)
        StartIndex = uint32(0);
        NoOfSamples_ptr = libpointer('uint32Ptr',NoOfSamples);
        DownSampleRatio = uint32(1);
        DownSampleRatioMode = int16(0);
        OverFlow = int16(20);
        OverFlow_ptr = libpointer('int16Ptr',OverFlow);
        [Status] = calllib('ps4000','ps4000GetValues',UnitHandle(k),StartIndex,NoOfSamples_ptr,DownSampleRatio,DownSampleRatioMode,SegmentIndex,OverFlow_ptr);
        disp(strcat('GetValues=',num2str(Status)));
        Data = double(get(Buffer_ptr,'value'));
        Voltage = Data*ChannelVRange(k,kk)/2^15;
        subplot(1,2,1);
        line(((1:length(Data))-Trigger(k).Position)*SamplePeriod,Voltage,'color',[0.2*kk 0 0]);
        subplot(1,2,2);
        line(((1:length(Data))-Trigger(k).Position),Data,'color',[0.2*kk 0 0]);
        xlim([-50 50]);
    end
    time2 = clock;
    disp(strcat('TimeData=',num2str(etime(time2,time1))))
end
clear Buffer_ptr


